@@ -36,7 +36,7 @@ using Tellico::Data::MusicCollection;
 
 MusicCollection::MusicCollection(bool addDefaultFields_, const QString& title_)
    : Collection(title_.isEmpty() ? i18n("My Music") : title_) {
-  setDefaultGroupField(QLatin1String("artist"));
+  setDefaultGroupField(QStringLiteral("artist"));
   if(addDefaultFields_) {
     addFields(defaultFields());
   }
@@ -52,73 +52,73 @@ Tellico::Data::FieldList MusicCollection::defaultFields() {
 
   QStringList media;
   media << i18n("Compact Disc") << i18n("DVD") << i18n("Cassette") << i18n("Vinyl");
-  field = new Field(QLatin1String("medium"), i18n("Medium"), media);
+  field = new Field(QStringLiteral("medium"), i18n("Medium"), media);
   field->setCategory(i18n(music_general));
   field->setFlags(Field::AllowGrouped);
   list.append(field);
 
-  field = new Field(QLatin1String("artist"), i18n("Artist"));
+  field = new Field(QStringLiteral("artist"), i18n("Artist"));
   field->setCategory(i18n(music_general));
   field->setFlags(Field::AllowCompletion | Field::AllowGrouped | Field::AllowMultiple);
   field->setFormatType(FieldFormat::FormatTitle); // don't use FormatName
   list.append(field);
 
-  field = new Field(QLatin1String("label"), i18n("Label"));
+  field = new Field(QStringLiteral("label"), i18n("Label"));
   field->setCategory(i18n(music_general));
   field->setFlags(Field::AllowCompletion | Field::AllowGrouped | Field::AllowMultiple);
   field->setFormatType(FieldFormat::FormatPlain);
   list.append(field);
 
-  field = new Field(QLatin1String("year"), i18n("Year"), Field::Number);
+  field = new Field(QStringLiteral("year"), i18n("Year"), Field::Number);
   field->setCategory(i18n(music_general));
   field->setFlags(Field::AllowGrouped);
   list.append(field);
 
-  field = new Field(QLatin1String("genre"), i18n("Genre"));
+  field = new Field(QStringLiteral("genre"), i18n("Genre"));
   field->setCategory(i18n(music_general));
   field->setFlags(Field::AllowCompletion | Field::AllowMultiple | Field::AllowGrouped);
   field->setFormatType(FieldFormat::FormatPlain);
   list.append(field);
 
-  field = new Field(QLatin1String("track"), i18n("Tracks"), Field::Table);
+  field = new Field(QStringLiteral("track"), i18n("Tracks"), Field::Table);
   field->setFormatType(FieldFormat::FormatTitle);
-  field->setProperty(QLatin1String("columns"), QLatin1String("3"));
-  field->setProperty(QLatin1String("column1"), i18n("Title"));
-  field->setProperty(QLatin1String("column2"), i18n("Artist"));
-  field->setProperty(QLatin1String("column3"), i18n("Length"));
+  field->setProperty(QStringLiteral("columns"), QStringLiteral("3"));
+  field->setProperty(QStringLiteral("column1"), i18n("Title"));
+  field->setProperty(QStringLiteral("column2"), i18n("Artist"));
+  field->setProperty(QStringLiteral("column3"), i18n("Length"));
   list.append(field);
 
-  field = new Field(QLatin1String("rating"), i18n("Rating"), Field::Rating);
+  field = new Field(QStringLiteral("rating"), i18n("Rating"), Field::Rating);
   field->setCategory(i18n(music_personal));
   field->setFlags(Field::AllowGrouped);
   list.append(field);
 
-  field = new Field(QLatin1String("pur_date"), i18n("Purchase Date"));
+  field = new Field(QStringLiteral("pur_date"), i18n("Purchase Date"));
   field->setCategory(i18n(music_personal));
   field->setFormatType(FieldFormat::FormatDate);
   list.append(field);
 
-  field = new Field(QLatin1String("gift"), i18n("Gift"), Field::Bool);
+  field = new Field(QStringLiteral("gift"), i18n("Gift"), Field::Bool);
   field->setCategory(i18n(music_personal));
   list.append(field);
 
-  field = new Field(QLatin1String("pur_price"), i18n("Purchase Price"));
+  field = new Field(QStringLiteral("pur_price"), i18n("Purchase Price"));
   field->setCategory(i18n(music_personal));
   list.append(field);
 
-  field = new Field(QLatin1String("loaned"), i18n("Loaned"), Field::Bool);
+  field = new Field(QStringLiteral("loaned"), i18n("Loaned"), Field::Bool);
   field->setCategory(i18n(music_personal));
   list.append(field);
 
-  field = new Field(QLatin1String("keyword"), i18n("Keywords"));
+  field = new Field(QStringLiteral("keyword"), i18n("Keywords"));
   field->setCategory(i18n(music_personal));
   field->setFlags(Field::AllowCompletion | Field::AllowMultiple | Field::AllowGrouped);
   list.append(field);
 
-  field = new Field(QLatin1String("cover"), i18n("Cover"), Field::Image);
+  field = new Field(QStringLiteral("cover"), i18n("Cover"), Field::Image);
   list.append(field);
 
-  field = new Field(QLatin1String("comments"), i18n("Comments"), Field::Para);
+  field = new Field(QStringLiteral("comments"), i18n("Comments"), Field::Para);
   field->setCategory(i18n(music_personal));
   list.append(field);
 
@@ -131,14 +131,14 @@ Tellico::Data::FieldList MusicCollection::defaultFields() {
 
 int MusicCollection::sameEntry(Tellico::Data::EntryPtr entry1_, Tellico::Data::EntryPtr entry2_) const {
   // not enough for title to be equal, must also have another field
-  int res = 2*EntryComparison::score(entry1_, entry2_, QLatin1String("title"), this);
+  int res = 2*EntryComparison::score(entry1_, entry2_, QStringLiteral("title"), this);
 //  if(res == 0) {
 //    myDebug() << "different titles for " << entry1_->title() << " vs. "
 //              << entry2_->title();
 //  }
-  res += 2*EntryComparison::score(entry1_, entry2_, QLatin1String("artist"), this);
-  res += EntryComparison::score(entry1_, entry2_, QLatin1String("year"), this);
-  res += EntryComparison::score(entry1_, entry2_, QLatin1String("label"), this);
-  res += EntryComparison::score(entry1_, entry2_, QLatin1String("medium"), this);
+  res += 2*EntryComparison::score(entry1_, entry2_, QStringLiteral("artist"), this);
+  res += EntryComparison::score(entry1_, entry2_, QStringLiteral("year"), this);
+  res += EntryComparison::score(entry1_, entry2_, QStringLiteral("label"), this);
+  res += EntryComparison::score(entry1_, entry2_, QStringLiteral("medium"), this);
   return res;
 }
