@@ -277,7 +277,11 @@ void Controller::slotClearSelection() {
   blockAllSignals(true);
 
   m_mainWindow->m_detailedView->clearSelection();
+  m_mainWindow->m_iconView->clearSelection();
   m_mainWindow->m_groupView->clearSelection();
+  if(m_mainWindow->m_filterView) {
+    m_mainWindow->m_filterView->clearSelection();
+  }
   if(m_mainWindow->m_loanView) {
     m_mainWindow->m_loanView->clearSelection();
   }
@@ -326,7 +330,7 @@ void Controller::slotDeleteSelectedEntries() {
   // confirm delete
   if(m_selectedEntries.count() == 1) {
     QString str = i18n("Do you really want to delete this entry?");
-    QString dontAsk = QLatin1String("DeleteEntry");
+    QString dontAsk = QStringLiteral("DeleteEntry");
     int ret = KMessageBox::warningContinueCancel(Kernel::self()->widget(), str, i18n("Delete Entry"),
                                                  KStandardGuiItem::del(),
                                                  KStandardGuiItem::cancel(), dontAsk);
@@ -341,7 +345,7 @@ void Controller::slotDeleteSelectedEntries() {
     }
     QString str = i18n("Do you really want to delete these entries?");
     // historically called DeleteMultipleBooks, don't change
-    QString dontAsk = QLatin1String("DeleteMultipleBooks");
+    QString dontAsk = QStringLiteral("DeleteMultipleBooks");
     int ret = KMessageBox::warningContinueCancelList(Kernel::self()->widget(), str, names,
                                                      i18n("Delete Multiple Entries"),
                                                      KStandardGuiItem::del(),
@@ -435,7 +439,10 @@ void Controller::slotUpdateFilter(Tellico::FilterPtr filter_) {
   updateActions();
 
   m_mainWindow->m_detailedView->setFilter(filter_); // takes ownership
-  if(!filter_ && m_mainWindow->m_filterView) { // for example, when quick filter clears the selection
+  if(!filter_ && m_mainWindow->m_filterView && !m_mainWindow->m_dontQueueFilter) {
+    // for example, when quick filter clears the selection
+    // the check against m_dontQueueFilter is to prevent the situation when the FilterView has an Entry selected
+    // which sends an empty filter selection, which would then clear the whole FilterView selection
     m_mainWindow->m_filterView->clearSelection();
   }
 
@@ -515,7 +522,7 @@ void Controller::plugUpdateMenu(QMenu* popup_) {
 
 void Controller::updateActions() const {
   const bool emptySelection = m_selectedEntries.isEmpty();
-  m_mainWindow->stateChanged(QLatin1String("empty_selection"),
+  m_mainWindow->stateChanged(QStringLiteral("empty_selection"),
                              emptySelection ? KXMLGUIClient::StateNoReverse : KXMLGUIClient::StateReverse);
   foreach(QAction* action, m_mainWindow->m_fetchActions) {
     action->setEnabled(!emptySelection);
@@ -656,7 +663,7 @@ void Controller::hideTabs() const {
 
 bool Controller::canCheckIn() const {
   foreach(Data::EntryPtr entry, m_selectedEntries) {
-    if(entry->field(QLatin1String("loaned")) == QLatin1String("true")) {
+    if(entry->field(QStringLiteral("loaned")) == QLatin1String("true")) {
       return true;
     }
   }
