@@ -49,6 +49,7 @@ public:
   EntryIconView(QWidget* parent);
   ~EntryIconView();
 
+  void setModel(QAbstractItemModel* model) Q_DECL_OVERRIDE;
   int maxAllowedIconWidth() const { return m_maxAllowedIconWidth; }
 
 public Q_SLOTS:
@@ -61,6 +62,7 @@ private Q_SLOTS:
   void slotDoubleClicked(const QModelIndex& index);
   void slotSortMenuActivated(QAction* action);
   void slotOpenUrlMenuActivated(QAction* action=nullptr);
+  void updateModelColumn();
 
 private:
   int m_maxAllowedIconWidth;
