@@ -40,22 +40,22 @@ class BiblioShareFetcher : public XMLFetcher {
 Q_OBJECT
 
 public:
-  BiblioShareFetcher(QObject* parent = 0);
+  BiblioShareFetcher(QObject* parent = nullptr);
   ~BiblioShareFetcher();
 
-  virtual QString source() const;
-  virtual bool canSearch(FetchKey k) const { return k == ISBN; }
-  virtual Type type() const { return BiblioShare; }
-  virtual bool canFetch(int type) const;
-  virtual void readConfigHook(const KConfigGroup& config);
+  virtual QString source() const Q_DECL_OVERRIDE;
+  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE { return k == ISBN; }
+  virtual Type type() const Q_DECL_OVERRIDE { return BiblioShare; }
+  virtual bool canFetch(int type) const Q_DECL_OVERRIDE;
+  virtual void readConfigHook(const KConfigGroup& config) Q_DECL_OVERRIDE;
 
-  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const;
+  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const Q_DECL_OVERRIDE;
 
   class ConfigWidget : public Fetch::ConfigWidget {
   public:
-    explicit ConfigWidget(QWidget* parent_, const BiblioShareFetcher* fetcher = 0);
-    virtual void saveConfigHook(KConfigGroup&);
-    virtual QString preferredName() const;
+    explicit ConfigWidget(QWidget* parent_, const BiblioShareFetcher* fetcher = nullptr);
+    virtual void saveConfigHook(KConfigGroup&) Q_DECL_OVERRIDE;
+    virtual QString preferredName() const Q_DECL_OVERRIDE;
   private:
     QLineEdit* m_tokenEdit;
   };
@@ -66,11 +66,11 @@ public:
   static StringHash allOptionalFields() { return StringHash(); }
 
 private:
-  virtual FetchRequest updateRequest(Data::EntryPtr entry);
-  virtual void resetSearch() {}
-  virtual QUrl searchUrl();
-  virtual void parseData(QByteArray&) {}
-  virtual Data::EntryPtr fetchEntryHookData(Data::EntryPtr entry);
+  virtual FetchRequest updateRequest(Data::EntryPtr entry) Q_DECL_OVERRIDE;
+  virtual void resetSearch() Q_DECL_OVERRIDE {}
+  virtual QUrl searchUrl() Q_DECL_OVERRIDE;
+  virtual void parseData(QByteArray&) Q_DECL_OVERRIDE {}
+  virtual Data::EntryPtr fetchEntryHookData(Data::EntryPtr entry) Q_DECL_OVERRIDE;
 
   QString m_token;
 };
