@@ -99,24 +99,24 @@ void DiscogsFetcher::search() {
   QUrlQuery q;
   switch(request().key) {
     case Title:
-      u.setPath(QLatin1String("/database/search"));
-      q.addQueryItem(QLatin1String("release_title"), request().value);
-      q.addQueryItem(QLatin1String("type"), QLatin1String("release"));
+      u.setPath(QStringLiteral("/database/search"));
+      q.addQueryItem(QStringLiteral("release_title"), request().value);
+      q.addQueryItem(QStringLiteral("type"), QStringLiteral("release"));
       break;
 
     case Person:
-      u.setPath(QLatin1String("/database/search"));
-      q.addQueryItem(QLatin1String("artist"), request().value);
-      q.addQueryItem(QLatin1String("type"), QLatin1String("release"));
+      u.setPath(QStringLiteral("/database/search"));
+      q.addQueryItem(QStringLiteral("artist"), request().value);
+      q.addQueryItem(QStringLiteral("type"), QStringLiteral("release"));
       break;
 
     case Keyword:
-      u.setPath(QLatin1String("/database/search"));
-      q.addQueryItem(QLatin1String("q"), request().value);
+      u.setPath(QStringLiteral("/database/search"));
+      q.addQueryItem(QStringLiteral("q"), request().value);
       break;
 
     case Raw:
-      u.setPath(QLatin1String("/database/search"));
+      u.setPath(QStringLiteral("/database/search"));
       q.setQuery(request().value);
       break;
 
@@ -125,13 +125,13 @@ void DiscogsFetcher::search() {
       stop();
       return;
   }
-  q.addQueryItem(QLatin1String("token"), m_apiKey);
+  q.addQueryItem(QStringLiteral("token"), m_apiKey);
   u.setQuery(q);
 
 //  myDebug() << "url: " << u.url();
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->addMetaData(QLatin1String("UserAgent"), QString::fromLatin1("Tellico/%1")
+  m_job->addMetaData(QStringLiteral("UserAgent"), QStringLiteral("Tellico/%1")
                                                                 .arg(QLatin1String(TELLICO_VERSION)));
   KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)), SLOT(slotComplete(KJob*)));
@@ -156,11 +156,11 @@ Tellico::Data::EntryPtr DiscogsFetcher::fetchEntryHook(uint uid_) {
     return Data::EntryPtr();
   }
 
-  QString id = entry->field(QLatin1String("discogs-id"));
+  QString id = entry->field(QStringLiteral("discogs-id"));
   if(!id.isEmpty()) {
     // quiet
     QUrl u(QString::fromLatin1(DISCOGS_API_URL));
-    u.setPath(QString::fromLatin1("/releases/%1").arg(id));
+    u.setPath(QStringLiteral("/releases/%1").arg(id));
     QByteArray data = FileHandler::readDataFile(u, true);
 
 #if 0
@@ -183,7 +183,7 @@ Tellico::Data::EntryPtr DiscogsFetcher::fetchEntryHook(uint uid_) {
     }
   }
 
-  const QString image_id = entry->field(QLatin1String("cover"));
+  const QString image_id = entry->field(QStringLiteral("cover"));
   // if it's still a url, we need to load it
   if(image_id.contains(QLatin1Char('/'))) {
     const QString id = ImageFactory::addImage(QUrl::fromUserInput(image_id), true /* quiet */);
@@ -192,22 +192,22 @@ Tellico::Data::EntryPtr DiscogsFetcher::fetchEntryHook(uint uid_) {
       message(i18n("The cover image could not be loaded."), MessageHandler::Warning);
     }
     // empty image ID is ok
-    entry->setField(QLatin1String("cover"), id);
+    entry->setField(QStringLiteral("cover"), id);
   }
 
   // don't want to include ID field
-  entry->setField(QLatin1String("discogs-id"), QString());
+  entry->setField(QStringLiteral("discogs-id"), QString());
 
   return entry;
 }
 
 Tellico::Fetch::FetchRequest DiscogsFetcher::updateRequest(Data::EntryPtr entry_) {
-  QString title = entry_->field(QLatin1String("title"));
+  QString title = entry_->field(QStringLiteral("title"));
   if(!title.isEmpty()) {
     return FetchRequest(Title, title);
   }
 
-  QString artist = entry_->field(QLatin1String("artist"));
+  QString artist = entry_->field(QStringLiteral("artist"));
   if(!artist.isEmpty()) {
     return FetchRequest(Person, artist);
   }
@@ -244,24 +244,24 @@ void DiscogsFetcher::slotComplete(KJob*) {
 
   Data::CollPtr coll(new Data::MusicCollection(true));
   // always add ID for fetchEntryHook
-  Data::FieldPtr field(new Data::Field(QLatin1String("discogs-id"), QLatin1String("Discogs ID"), Data::Field::Line));
+  Data::FieldPtr field(new Data::Field(QStringLiteral("discogs-id"), QStringLiteral("Discogs ID"), Data::Field::Line));
   field->setCategory(i18n("General"));
   coll->addField(field);
 
   if(optionalFields().contains(QLatin1String("discogs"))) {
-    Data::FieldPtr field(new Data::Field(QLatin1String("discogs"), i18n("Discogs Link"), Data::Field::URL));
+    Data::FieldPtr field(new Data::Field(QStringLiteral("discogs"), i18n("Discogs Link"), Data::Field::URL));
     field->setCategory(i18n("General"));
     coll->addField(field);
   }
   if(optionalFields().contains(QLatin1String("nationality"))) {
-    Data::FieldPtr field(new Data::Field(QLatin1String("nationality"), i18n("Nationality")));
+    Data::FieldPtr field(new Data::Field(QStringLiteral("nationality"), i18n("Nationality")));
     field->setCategory(i18n("General"));
     field->setFlags(Data::Field::AllowCompletion | Data::Field::AllowMultiple | Data::Field::AllowGrouped);
     field->setFormatType(FieldFormat::FormatPlain);
     coll->addField(field);
   }
   if(optionalFields().contains(QLatin1String("producer"))) {
-    Data::FieldPtr field(new Data::Field(QLatin1String("producer"), i18n("Producer")));
+    Data::FieldPtr field(new Data::Field(QStringLiteral("producer"), i18n("Producer")));
     field->setCategory(i18n("General"));
     field->setFlags(Data::Field::AllowCompletion | Data::Field::AllowMultiple | Data::Field::AllowGrouped);
     field->setFormatType(FieldFormat::FormatName);
@@ -269,7 +269,7 @@ void DiscogsFetcher::slotComplete(KJob*) {
   }
 
   QJsonDocument doc = QJsonDocument::fromJson(data);
-//  const QVariantMap resultMap = doc.object().toVariantMap().value(QLatin1String("feed")).toMap();
+//  const QVariantMap resultMap = doc.object().toVariantMap().value(QStringLiteral("feed")).toMap();
   const QVariantMap resultMap = doc.object().toVariantMap();
 
   if(mapValue(resultMap, "message").startsWith(QLatin1String("Invalid consumer token"))) {
@@ -280,7 +280,7 @@ void DiscogsFetcher::slotComplete(KJob*) {
   }
 
   int count = 0;
-  foreach(const QVariant& result, resultMap.value(QLatin1String("results")).toList()) {
+  foreach(const QVariant& result, resultMap.value(QStringLiteral("results")).toList()) {
     if(count >= DISCOGS_MAX_RETURNS_TOTAL) {
       break;
     }
@@ -300,27 +300,27 @@ void DiscogsFetcher::slotComplete(KJob*) {
 }
 
 void DiscogsFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& resultMap_, bool fullData_) {
-  entry_->setField(QLatin1String("discogs-id"), mapValue(resultMap_, "id"));
-  entry_->setField(QLatin1String("title"), mapValue(resultMap_, "title"));
-  entry_->setField(QLatin1String("year"),  mapValue(resultMap_, "year"));
-  entry_->setField(QLatin1String("genre"),  mapValue(resultMap_, "genres"));
+  entry_->setField(QStringLiteral("discogs-id"), mapValue(resultMap_, "id"));
+  entry_->setField(QStringLiteral("title"), mapValue(resultMap_, "title"));
+  entry_->setField(QStringLiteral("year"),  mapValue(resultMap_, "year"));
+  entry_->setField(QStringLiteral("genre"),  mapValue(resultMap_, "genres"));
 
   QStringList artists;
-  foreach(const QVariant& artist, resultMap_.value(QLatin1String("artists")).toList()) {
+  foreach(const QVariant& artist, resultMap_.value(QStringLiteral("artists")).toList()) {
     artists << mapValue(artist.toMap(), "name");
   }
-  entry_->setField(QLatin1String("artist"), artists.join(FieldFormat::delimiterString()));
+  entry_->setField(QStringLiteral("artist"), artists.join(FieldFormat::delimiterString()));
 
   QStringList labels;
-  foreach(const QVariant& label, resultMap_.value(QLatin1String("labels")).toList()) {
+  foreach(const QVariant& label, resultMap_.value(QStringLiteral("labels")).toList()) {
     labels << mapValue(label.toMap(), "name");
   }
-  entry_->setField(QLatin1String("label"), labels.join(FieldFormat::delimiterString()));
+  entry_->setField(QStringLiteral("label"), labels.join(FieldFormat::delimiterString()));
 
   /* thumb value is not always in the full data, so go ahead and set it now */
   QString coverUrl = mapValue(resultMap_, "thumb");
   if(!coverUrl.isEmpty()) {
-    entry_->setField(QLatin1String("cover"), coverUrl);
+    entry_->setField(QStringLiteral("cover"), coverUrl);
   }
 
   // if we only need cursory data, then we're done
@@ -331,22 +331,22 @@ void DiscogsFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& res
   // check the formats, it could have multiple
   // if there is a CD, prefer that in the track list
   bool hasCD = false;
-  foreach(const QVariant& format, resultMap_.value(QLatin1String("formats")).toList()) {
+  foreach(const QVariant& format, resultMap_.value(QStringLiteral("formats")).toList()) {
     if(mapValue(format.toMap(), "name") == QLatin1String("CD")) {
-      entry_->setField(QLatin1String("medium"), i18n("Compact Disc"));
+      entry_->setField(QStringLiteral("medium"), i18n("Compact Disc"));
       hasCD = true;
     } else if(mapValue(format.toMap(), "name") == QLatin1String("Vinyl")) {
-      entry_->setField(QLatin1String("medium"), i18n("Vinyl"));
+      entry_->setField(QStringLiteral("medium"), i18n("Vinyl"));
     } else if(mapValue(format.toMap(), "name") == QLatin1String("Cassette")) {
-      entry_->setField(QLatin1String("medium"), i18n("Cassette"));
+      entry_->setField(QStringLiteral("medium"), i18n("Cassette"));
     } else if(!hasCD && mapValue(format.toMap(), "name") == QLatin1String("DVD")) {
       // sometimes a CD and DVD both are included. If we're using the CD, ignore the DVD
-      entry_->setField(QLatin1String("medium"), i18n("DVD"));
+      entry_->setField(QStringLiteral("medium"), i18n("DVD"));
     }
   }
 
   QStringList tracks;
-  foreach(const QVariant& track, resultMap_.value(QLatin1String("tracklist")).toList()) {
+  foreach(const QVariant& track, resultMap_.value(QStringLiteral("tracklist")).toList()) {
     const QVariantMap trackMap = track.toMap();
     if(mapValue(trackMap, "type_") != QLatin1String("track")) {
       continue;
@@ -361,39 +361,39 @@ void DiscogsFetcher::populateEntry(Data::EntryPtr entry_, const QVariantMap& res
 
     QStringList trackInfo;
     trackInfo << mapValue(trackMap, "title");
-    if(trackMap.contains(QLatin1String("artists"))) {
+    if(trackMap.contains(QStringLiteral("artists"))) {
       QStringList artists;
-      foreach(const QVariant& artist, trackMap.value(QLatin1String("artists")).toList()) {
+      foreach(const QVariant& artist, trackMap.value(QStringLiteral("artists")).toList()) {
         artists << mapValue(artist.toMap(), "name");
       }
       trackInfo << artists.join(FieldFormat::delimiterString());
     } else {
-      trackInfo << entry_->field(QLatin1String("artist"));
+      trackInfo << entry_->field(QStringLiteral("artist"));
     }
     trackInfo << mapValue(trackMap, "duration");
     tracks << trackInfo.join(FieldFormat::columnDelimiterString());
   }
-  entry_->setField(QLatin1String("track"), tracks.join(FieldFormat::rowDelimiterString()));
+  entry_->setField(QStringLiteral("track"), tracks.join(FieldFormat::rowDelimiterString()));
 
-  if(entry_->collection()->hasField(QLatin1String("discogs"))) {
-    entry_->setField(QLatin1String("discogs"), mapValue(resultMap_, "uri"));
+  if(entry_->collection()->hasField(QStringLiteral("discogs"))) {
+    entry_->setField(QStringLiteral("discogs"), mapValue(resultMap_, "uri"));
   }
 
-  if(entry_->collection()->hasField(QLatin1String("nationality"))) {
-    entry_->setField(QLatin1String("nationality"), mapValue(resultMap_, "country"));
+  if(entry_->collection()->hasField(QStringLiteral("nationality"))) {
+    entry_->setField(QStringLiteral("nationality"), mapValue(resultMap_, "country"));
   }
 
-  if(entry_->collection()->hasField(QLatin1String("producer"))) {
+  if(entry_->collection()->hasField(QStringLiteral("producer"))) {
     QStringList producers;
-    foreach(const QVariant& extraartist, resultMap_.value(QLatin1String("extraartists")).toList()) {
+    foreach(const QVariant& extraartist, resultMap_.value(QStringLiteral("extraartists")).toList()) {
       if(mapValue(extraartist.toMap(), "role").contains(QLatin1String("Producer"))) {
         producers << mapValue(extraartist.toMap(), "name");
       }
     }
-    entry_->setField(QLatin1String("producer"), producers.join(FieldFormat::delimiterString()));
+    entry_->setField(QStringLiteral("producer"), producers.join(FieldFormat::delimiterString()));
   }
 
-  entry_->setField(QLatin1String("comments"),  mapValue(resultMap_, "notes"));
+  entry_->setField(QStringLiteral("comments"), mapValue(resultMap_, "notes"));
 }
 
 Tellico::Fetch::ConfigWidget* DiscogsFetcher::configWidget(QWidget* parent_) const {
@@ -410,9 +410,9 @@ QString DiscogsFetcher::defaultIcon() {
 
 Tellico::StringHash DiscogsFetcher::allOptionalFields() {
   StringHash hash;
-  hash[QLatin1String("producer")] = i18n("Producer");
-  hash[QLatin1String("nationality")] = i18n("Nationality");
-  hash[QLatin1String("discogs")] = i18n("Discogs Link");
+  hash[QStringLiteral("producer")] = i18n("Producer");
+  hash[QStringLiteral("nationality")] = i18n("Nationality");
+  hash[QStringLiteral("discogs")] = i18n("Discogs Link");
   return hash;
 }
 
