@@ -25,7 +25,7 @@
 #ifndef TELLICO_DOUBANFETCHER_H
 #define TELLICO_DOUBANFETCHER_H
 
-#include "xmlfetcher.h"
+#include "fetcher.h"
 #include "configwidget.h"
 #include "../datavectors.h"
 
@@ -36,7 +36,6 @@ class KJob;
 namespace KIO {
   class StoredTransferJob;
 }
-class KLineEdit;
 
 namespace Tellico {
   namespace Fetch {
@@ -44,7 +43,7 @@ namespace Tellico {
 /**
  * @author Robby Stephenson
  */
-class DoubanFetcher : public XMLFetcher {
+class DoubanFetcher : public Fetcher {
 Q_OBJECT
 
 public:
@@ -57,24 +56,25 @@ public:
 
   /**
    */
-  virtual QString source() const;
-  virtual bool canSearch(FetchKey k) const;
-  virtual Type type() const { return Douban; }
-  virtual bool canFetch(int type) const;
-  virtual void readConfigHook(const KConfigGroup& config);
+  virtual QString source() const Q_DECL_OVERRIDE;
+  virtual bool isSearching() const Q_DECL_OVERRIDE { return m_started; }
+  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE;
+  virtual Type type() const Q_DECL_OVERRIDE { return Douban; }
+  virtual bool canFetch(int type) const Q_DECL_OVERRIDE;
+  virtual void stop() Q_DECL_OVERRIDE;
+  virtual Data::EntryPtr fetchEntryHook(uint uid) Q_DECL_OVERRIDE;
+  virtual void readConfigHook(const KConfigGroup& config) Q_DECL_OVERRIDE;
 
   /**
    * Returns a widget for modifying the fetcher's config.
    */
-  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const;
+  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const Q_DECL_OVERRIDE;
 
   class ConfigWidget : public Fetch::ConfigWidget {
   public:
-    explicit ConfigWidget(QWidget* parent_, const DoubanFetcher* fetcher = 0);
-    virtual void saveConfigHook(KConfigGroup&);
-    virtual QString preferredName() const;
-  private:
-    KLineEdit* m_apiKeyEdit;
+    explicit ConfigWidget(QWidget* parent_, const DoubanFetcher* fetcher = nullptr);
+    virtual void saveConfigHook(KConfigGroup&) Q_DECL_OVERRIDE;
+    virtual QString preferredName() const Q_DECL_OVERRIDE;
   };
   friend class ConfigWidget;
 
@@ -82,14 +82,24 @@ public:
   static QString defaultIcon();
   static StringHash allOptionalFields();
 
+private Q_SLOTS:
+  void slotComplete(KJob* job);
+  void slotCompleteISBN(KJob* job);
+
 private:
-  virtual FetchRequest updateRequest(Data::EntryPtr entry);
+  virtual void search() Q_DECL_OVERRIDE;
+  virtual FetchRequest updateRequest(Data::EntryPtr entry) Q_DECL_OVERRIDE;
   virtual void resetSearch() {}
-  virtual KUrl searchUrl();
-  virtual void parseData(QByteArray&) {}
-  virtual Data::EntryPtr fetchEntryHookData(Data::EntryPtr entry);
-  
-  QString m_apiKey;
+  Data::EntryPtr createEntry(const QVariantMap& resultMap);
+  void populateBookEntry(Data::EntryPtr entry, const QVariantMap& resultMap);
+  void populateVideoEntry(Data::EntryPtr entry, const QVariantMap& resultMap);
+  void populateMusicEntry(Data::EntryPtr entry, const QVariantMap& resultMap);
+
+  bool m_started;
+
+  QHash<int, QUrl> m_matches;
+  QHash<int, Data::EntryPtr> m_entries;
+  QPointer<KIO::StoredTransferJob> m_job;
 };
 
   } // end namespace
