@@ -57,13 +57,13 @@ enum Type {
   SRU,
   Entrez,
   ExecExternal,
-  Yahoo,
+  Yahoo, // Removed
   AnimeNfo,
   IBS,
   ISBNdb,
   GCstarPlugin,
   CrossRef,
-  Citebase,
+  Citebase, // Removed
   Arxiv,
   Bibsonomy,
   GoogleScholar,
@@ -74,24 +74,33 @@ enum Type {
   GiantBomb,
   OpenLibrary,
   Multiple,
-  Freebase,
+  Freebase, // Removed
   DVDFr,
   Filmaster,
   Douban,
   BiblioShare,
   MovieMeter,
   GoogleBook,
-  MAS,
+  MAS, // Removed
   Springer,
   Allocine,
-  ScreenRush,
-  FilmStarts,
-  SensaCine,
-  Beyazperde,
+  ScreenRush, // Removed
+  FilmStarts, // Removed
+  SensaCine, // Removed
+  Beyazperde, // Removed
   HathiTrust,
   TheGamesDB,
   DBLP,
-  VNDB
+  VNDB,
+  MRLookup,
+  BoardGameGeek,
+  Bedetheque,
+  OMDB,
+  KinoPoisk,
+  VideoGameGeek,
+  DBC,
+  IGDB,
+  Kino
 };
 
   }
