@@ -30,7 +30,7 @@
 #include "../datavectors.h"
 
 #include <QPointer>
-#include <QTime>
+#include <QElapsedTimer>
 
 class KJob;
 namespace KIO {
@@ -102,7 +102,7 @@ private:
   int m_limit;
   int m_total;
   int m_offset;
-  QTime m_requestTime;
+  QElapsedTimer m_requestTimer;
 
   QHash<int, Data::EntryPtr> m_entries;
   QPointer<KIO::StoredTransferJob> m_job;
