@@ -25,16 +25,17 @@
 #include "thegamesdbfetcher.h"
 #include "../translators/xslthandler.h"
 #include "../translators/tellicoimporter.h"
-#include "../tellico_utils.h"
+#include "../utils/string_utils.h"
 #include "../tellico_debug.h"
 
-#include <klocale.h>
+#include <KLocalizedString>
 #include <KConfigGroup>
 
 #include <QLabel>
 #include <QFile>
 #include <QTextStream>
 #include <QVBoxLayout>
+#include <QUrlQuery>
 
 namespace {
   static const char* THEGAMESDB_SEARCH_API_URL = "http://thegamesdb.net/api/GetGamesList.php";
@@ -47,7 +48,7 @@ using Tellico::Fetch::TheGamesDBFetcher;
 TheGamesDBFetcher::TheGamesDBFetcher(QObject* parent_)
     : XMLFetcher(parent_) {
   setLimit(10);
-  setXSLTFilename(QLatin1String("thegamesdb2tellico.xsl"));
+  setXSLTFilename(QStringLiteral("thegamesdb2tellico.xsl"));
 }
 
 TheGamesDBFetcher::~TheGamesDBFetcher() {
@@ -61,24 +62,26 @@ bool TheGamesDBFetcher::canFetch(int type) const {
   return type == Data::Collection::Game;
 }
 
-KUrl TheGamesDBFetcher::searchUrl() {
-  KUrl u;
+QUrl TheGamesDBFetcher::searchUrl() {
+  QUrl u;
 
+  QUrlQuery q;
   switch(request().key) {
     case Title:
-      u = KUrl(THEGAMESDB_DETAIL_API_URL);
-      u.addQueryItem(QLatin1String("name"), request().value);
+      u = QUrl(QString::fromLatin1(THEGAMESDB_DETAIL_API_URL));
+      q.addQueryItem(QStringLiteral("name"), request().value);
       break;
 
     case Keyword:
-      u = KUrl(THEGAMESDB_SEARCH_API_URL);
-      u.addQueryItem(QLatin1String("name"), request().value);
+      u = QUrl(QString::fromLatin1(THEGAMESDB_SEARCH_API_URL));
+      q.addQueryItem(QStringLiteral("name"), request().value);
       break;
 
     default:
       myWarning() << "key not recognized: " << request().key;
-      return KUrl();
+      return QUrl();
   }
+  u.setQuery(q);
 
 //  myDebug() << "url: " << u.url();
   return u;
@@ -87,14 +90,16 @@ KUrl TheGamesDBFetcher::searchUrl() {
 Tellico::Data::EntryPtr TheGamesDBFetcher::fetchEntryHookData(Data::EntryPtr entry_) {
   Q_ASSERT(entry_);
 
-  const QString id = entry_->field(QLatin1String("thegamesdb-id"));
+  const QString id = entry_->field(QStringLiteral("thegamesdb-id"));
   if(id.isEmpty()) {
     myDebug() << "no id found";
     return entry_;
   }
 
-  KUrl u(THEGAMESDB_DETAIL_API_URL);
-  u.addQueryItem(QLatin1String("id"), id);
+  QUrl u(QString::fromLatin1(THEGAMESDB_DETAIL_API_URL));
+  QUrlQuery q;
+  q.addQueryItem(QStringLiteral("id"), id);
+  u.setQuery(q);
 //  myDebug() << "url: " << u;
 
   // quiet
@@ -126,12 +131,12 @@ Tellico::Data::EntryPtr TheGamesDBFetcher::fetchEntryHookData(Data::EntryPtr ent
   }
 
   // don't want to include id
-  coll->removeField(QLatin1String("thegamesdb-id"));
+  coll->removeField(QStringLiteral("thegamesdb-id"));
   return coll->entries().front();
 }
 
 Tellico::Fetch::FetchRequest TheGamesDBFetcher::updateRequest(Data::EntryPtr entry_) {
-  QString title = entry_->field(QLatin1String("title"));
+  QString title = entry_->field(QStringLiteral("title"));
   if(!title.isEmpty()) {
     return FetchRequest(Title, title);
   }
@@ -143,7 +148,7 @@ Tellico::Fetch::ConfigWidget* TheGamesDBFetcher::configWidget(QWidget* parent_)
 }
 
 QString TheGamesDBFetcher::defaultName() {
-  return QLatin1String("TheGamesDB.net");
+  return QStringLiteral("TheGamesDB.net");
 }
 
 QString TheGamesDBFetcher::defaultIcon() {
@@ -171,5 +176,3 @@ void TheGamesDBFetcher::ConfigWidget::saveConfigHook(KConfigGroup&) {
 QString TheGamesDBFetcher::ConfigWidget::preferredName() const {
   return TheGamesDBFetcher::defaultName();
 }
-
-#include "thegamesdbfetcher.moc"
