@@ -29,8 +29,7 @@
 #include "configwidget.h"
 #include "../datavectors.h"
 
-#include <klineedit.h>
-
+#include <QLineEdit>
 #include <QPointer>
 #include <QDate>
 
@@ -48,7 +47,7 @@ namespace Tellico {
   namespace Fetch {
 
 /**
- * A fetcher for discogs.com
+ * A fetcher for themoviedb.org
  *
  * @author Robby Stephenson
  */
@@ -65,22 +64,22 @@ public:
 
   /**
    */
-  virtual QString source() const;
-  virtual QString attribution() const;
-  virtual bool isSearching() const { return m_started; }
-  virtual bool canSearch(FetchKey k) const;
-  virtual void stop();
-  virtual Data::EntryPtr fetchEntryHook(uint uid);
-  virtual Type type() const { return TheMovieDB; }
-  virtual bool canFetch(int type) const;
-  virtual void readConfigHook(const KConfigGroup& config);
-  virtual void saveConfigHook(KConfigGroup& config);
-  virtual void continueSearch();
+  virtual QString source() const Q_DECL_OVERRIDE;
+  virtual QString attribution() const Q_DECL_OVERRIDE;
+  virtual bool isSearching() const Q_DECL_OVERRIDE { return m_started; }
+  virtual bool canSearch(FetchKey k) const Q_DECL_OVERRIDE;
+  virtual void stop() Q_DECL_OVERRIDE;
+  virtual Data::EntryPtr fetchEntryHook(uint uid) Q_DECL_OVERRIDE;
+  virtual Type type() const Q_DECL_OVERRIDE { return TheMovieDB; }
+  virtual bool canFetch(int type) const Q_DECL_OVERRIDE;
+  virtual void readConfigHook(const KConfigGroup& config) Q_DECL_OVERRIDE;
+  virtual void saveConfigHook(KConfigGroup& config) Q_DECL_OVERRIDE;
+  virtual void continueSearch() Q_DECL_OVERRIDE;
 
   /**
    * Returns a widget for modifying the fetcher's config.
    */
-  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const;
+  virtual Fetch::ConfigWidget* configWidget(QWidget* parent) const Q_DECL_OVERRIDE;
 
   class ConfigWidget;
   friend class ConfigWidget;
@@ -89,17 +88,15 @@ public:
   static QString defaultIcon();
   static StringHash allOptionalFields();
 
-private slots:
+private Q_SLOTS:
   void slotComplete(KJob* job);
 
 private:
-  virtual void search();
-  virtual FetchRequest updateRequest(Data::EntryPtr entry);
+  virtual void search() Q_DECL_OVERRIDE;
+  virtual FetchRequest updateRequest(Data::EntryPtr entry) Q_DECL_OVERRIDE;
   void populateEntry(Data::EntryPtr entry, const QVariantMap& resultMap, bool fullData);
   void readConfiguration();
 
-  static QString value(const QVariantMap& map, const char* name);
-
   bool m_started;
 
   QString m_locale;
@@ -115,15 +112,15 @@ class TheMovieDBFetcher::ConfigWidget : public Fetch::ConfigWidget {
 Q_OBJECT
 
 public:
-  explicit ConfigWidget(QWidget* parent_, const TheMovieDBFetcher* fetcher = 0);
-  virtual void saveConfigHook(KConfigGroup&);
-  virtual QString preferredName() const;
+  explicit ConfigWidget(QWidget* parent_, const TheMovieDBFetcher* fetcher = nullptr);
+  virtual void saveConfigHook(KConfigGroup&) Q_DECL_OVERRIDE;
+  virtual QString preferredName() const Q_DECL_OVERRIDE;
 
-private slots:
+private Q_SLOTS:
   void slotLangChanged();
 
 private:
-  KLineEdit* m_apiKeyEdit;
+  QLineEdit* m_apiKeyEdit;
   GUI::ComboBox* m_langCombo;
 };
 
