@@ -92,7 +92,7 @@ void VNDBFetcher::search() {
   }
 
   //the client ver only wants digits, I think?
-  QString clientVersion(QLatin1String(TELLICO_VERSION));
+  QString clientVersion(QStringLiteral(TELLICO_VERSION));
   clientVersion.remove(QRegExp(QLatin1String("[^0-9.]")));
 
   QByteArray login = "login {"
@@ -149,21 +149,21 @@ Tellico::Data::EntryPtr VNDBFetcher::fetchEntryHook(uint uid_) {
   }
 
   // image might still be a URL
-  const QString image_id = entry->field(QLatin1String("cover"));
+  const QString image_id = entry->field(QStringLiteral("cover"));
   if(image_id.contains(QLatin1Char('/'))) {
     const QString id = ImageFactory::addImage(QUrl::fromUserInput(image_id), true /* quiet */);
     if(id.isEmpty()) {
       message(i18n("The cover image could not be loaded."), MessageHandler::Warning);
     }
     // empty image ID is ok
-    entry->setField(QLatin1String("cover"), id);
+    entry->setField(QStringLiteral("cover"), id);
   }
 
   return entry;
 }
 
 Tellico::Fetch::FetchRequest VNDBFetcher::updateRequest(Data::EntryPtr entry_) {
-  const QString title = entry_->field(QLatin1String("title"));
+  const QString title = entry_->field(QStringLiteral("title"));
   if(!title.isEmpty()) {
     return FetchRequest(Title, title);
   }
@@ -184,9 +184,9 @@ void VNDBFetcher::slotComplete() {
   if(data.startsWith("error")) { //krazy:exclude=strings
     QJsonDocument doc = QJsonDocument::fromJson(data.mid(5));
     QVariantMap result = doc.object().toVariantMap();
-    if(result.contains(QLatin1String("msg"))) {
-      myDebug() << result.value(QLatin1String("msg")).toString();
-      message(result.value(QLatin1String("msg")).toString(), MessageHandler::Error);
+    if(result.contains(QStringLiteral("msg"))) {
+      myDebug() << result.value(QStringLiteral("msg")).toString();
+      message(result.value(QStringLiteral("msg")).toString(), MessageHandler::Error);
     }
     stop();
     return;
@@ -231,7 +231,7 @@ void VNDBFetcher::slotComplete() {
     return;
   }
   QVariantMap topResultMap = doc.object().toVariantMap();
-  QVariantList resultList = topResultMap.value(QLatin1String("items")).toList();
+  QVariantList resultList = topResultMap.value(QStringLiteral("items")).toList();
   if(resultList.isEmpty()) {
     myDebug() << "no results";
     stop();
@@ -241,12 +241,12 @@ void VNDBFetcher::slotComplete() {
   Data::CollPtr coll(new Data::GameCollection(true));
   // add new fields
   if(optionalFields().contains(QLatin1String("origtitle"))) {
-    Data::FieldPtr f(new Data::Field(QLatin1String("origtitle"), i18n("Original Title")));
+    Data::FieldPtr f(new Data::Field(QStringLiteral("origtitle"), i18n("Original Title")));
     f->setFormatType(FieldFormat::FormatTitle);
     coll->addField(f);
   }
   if(optionalFields().contains(QLatin1String("alias"))) {
-    Data::FieldPtr f(new Data::Field(QLatin1String("alias"), i18n("Alias")));
+    Data::FieldPtr f(new Data::Field(QStringLiteral("alias"), i18n("Alias")));
     f->setFlags(Data::Field::AllowMultiple);
     f->setFormatType(FieldFormat::FormatTitle);
     coll->addField(f);
@@ -262,17 +262,17 @@ void VNDBFetcher::slotComplete() {
     resultMap = result.toMap();
 
     Data::EntryPtr entry(new Data::Entry(coll));
-    entry->setField(QLatin1String("title"), mapValue(resultMap, "title"));
-    entry->setField(QLatin1String("year"), mapValue(resultMap, "released").left(4));
-    entry->setField(QLatin1String("genre"), i18n("Visual Novel"));
-    entry->setField(QLatin1String("description"), mapValue(resultMap, "description"));
-    entry->setField(QLatin1String("cover"), mapValue(resultMap, "image"));
+    entry->setField(QStringLiteral("title"), mapValue(resultMap, "title"));
+    entry->setField(QStringLiteral("year"), mapValue(resultMap, "released").left(4));
+    entry->setField(QStringLiteral("genre"), i18n("Visual Novel"));
+    entry->setField(QStringLiteral("description"), mapValue(resultMap, "description"));
+    entry->setField(QStringLiteral("cover"), mapValue(resultMap, "image"));
     if(optionalFields().contains(QLatin1String("origtitle"))) {
-      entry->setField(QLatin1String("origtitle"), mapValue(resultMap, "original"));
+      entry->setField(QStringLiteral("origtitle"), mapValue(resultMap, "original"));
     }
     if(optionalFields().contains(QLatin1String("alias"))) {
       const QString aliases = mapValue(resultMap, "aliases");
-      entry->setField(QLatin1String("alias"), aliases.split(QLatin1String("\n")).join(FieldFormat::delimiterString()));
+      entry->setField(QStringLiteral("alias"), aliases.split(QStringLiteral("\n")).join(FieldFormat::delimiterString()));
     }
 
     FetchResult* r = new FetchResult(Fetcher::Ptr(this), entry);
@@ -320,7 +320,7 @@ Tellico::Fetch::ConfigWidget* VNDBFetcher::configWidget(QWidget* parent_) const
 }
 
 QString VNDBFetcher::defaultName() {
-  return QLatin1String("Visual Novel Database"); // no translation
+  return QStringLiteral("Visual Novel Database"); // no translation
 }
 
 QString VNDBFetcher::defaultIcon() {
@@ -329,8 +329,8 @@ QString VNDBFetcher::defaultIcon() {
 
 Tellico::StringHash VNDBFetcher::allOptionalFields() {
   StringHash hash;
-  hash[QLatin1String("origtitle")] = i18n("Original Title");
-  hash[QLatin1String("alias")] = i18n("Alias");
+  hash[QStringLiteral("origtitle")] = i18n("Original Title");
+  hash[QStringLiteral("alias")] = i18n("Alias");
   return hash;
 }
 
