@@ -25,30 +25,31 @@
 #include "xmlfetcher.h"
 #include "../translators/xslthandler.h"
 #include "../translators/tellicoimporter.h"
-#include "../gui/guiproxy.h"
+#include "../utils/guiproxy.h"
 #include "../utils/xmlhandler.h"
-#include "../tellico_utils.h"
+#include "../utils/string_utils.h"
+#include "../utils/datafileregistry.h"
 #include "../tellico_debug.h"
 
-#include <kstandarddirs.h>
-#include <kio/job.h>
-#include <kio/jobuidelegate.h>
+#include <KIO/Job>
+#include <KIO/JobUiDelegate>
 
 #include <QFile>
 #include <QTextStream>
 #include <QTextCodec>
+#include <KJobWidgets/KJobWidgets>
 
 using Tellico::Fetch::XMLFetcher;
 
 XMLFetcher::XMLFetcher(QObject* parent_) : Fetcher(parent_)
-    , m_xsltHandler(0)
+    , m_xsltHandler(nullptr)
     , m_started(false)
     , m_limit(0) {
 }
 
 XMLFetcher::~XMLFetcher() {
   delete m_xsltHandler;
-  m_xsltHandler = 0;
+  m_xsltHandler = nullptr;
 }
 
 void XMLFetcher::search() {
@@ -63,7 +64,7 @@ void XMLFetcher::continueSearch() {
 }
 
 void XMLFetcher::doSearch() {
-  const KUrl u = searchUrl();
+  const QUrl u = searchUrl();
   Q_ASSERT(!u.isEmpty());
   if(u.isEmpty()) {
     stop();
@@ -72,7 +73,7 @@ void XMLFetcher::doSearch() {
 //  myDebug() << "url: " << u.url();
 
   m_job = KIO::storedGet(u, KIO::NoReload, KIO::HideProgressInfo);
-  m_job->ui()->setWindow(GUI::Proxy::widget());
+  KJobWidgets::setWindow(m_job, GUI::Proxy::widget());
   connect(m_job, SIGNAL(result(KJob*)), SLOT(slotComplete(KJob*)));
 }
 
@@ -82,7 +83,7 @@ void XMLFetcher::stop() {
   }
   if(m_job) {
     m_job->kill();
-    m_job = 0;
+    m_job = nullptr;
   }
   m_started = false;
   emit signalDone(this);
@@ -91,7 +92,7 @@ void XMLFetcher::stop() {
 void XMLFetcher::slotComplete(KJob* ) {
   Q_ASSERT(m_job);
   if(m_job->error()) {
-    m_job->ui()->showErrorMessage();
+    m_job->uiDelegate()->showErrorMessage();
     stop();
     return;
   }
@@ -112,7 +113,7 @@ void XMLFetcher::slotComplete(KJob* ) {
   }
   // see bug 319662. If fetcher is cancelled, job is killed
   // if the pointer is retained, it gets double-deleted
-  m_job = 0;
+  m_job = nullptr;
 
 #if 0
   myWarning() << "Remove debug from xmlfetcher.cpp";
@@ -186,21 +187,20 @@ Tellico::Data::EntryPtr XMLFetcher::fetchEntryHook(uint uid_) {
 
 void XMLFetcher::initXSLTHandler() {
   Q_ASSERT(!m_xsltFilename.isEmpty());
-  QString xsltfile = KStandardDirs::locate("appdata", m_xsltFilename);
+  QString xsltfile = DataFileRegistry::self()->locate(m_xsltFilename);
   if(xsltfile.isEmpty()) {
     myWarning() << "can not locate" << m_xsltFilename;
     return;
   }
 
-  KUrl u;
-  u.setPath(xsltfile);
+  QUrl u = QUrl::fromLocalFile(xsltfile);
 
   delete m_xsltHandler;
   m_xsltHandler = new XSLTHandler(u);
   if(!m_xsltHandler->isValid()) {
     myWarning() << "error in" << m_xsltFilename;
     delete m_xsltHandler;
-    m_xsltHandler = 0;
+    m_xsltHandler = nullptr;
     return;
   }
 }
@@ -209,7 +209,7 @@ void XMLFetcher::setXSLTFilename(const QString& filename_) {
   if(!filename_.isEmpty() && filename_ != m_xsltFilename) {
     m_xsltFilename = filename_;
     delete m_xsltHandler;
-    m_xsltHandler = 0;
+    m_xsltHandler = nullptr;
   }
 }
 
@@ -222,5 +222,3 @@ Tellico::XSLTHandler* XMLFetcher::xsltHandler() {
   Q_ASSERT(m_xsltHandler);
   return m_xsltHandler;
 }
-
-#include "xmlfetcher.moc"
