@@ -27,8 +27,6 @@
 
 #include "datavectors.h"
 
-#include <ksharedptr.h>
-
 #include <QList>
 #include <QString>
 #include <QVariant>
@@ -53,7 +51,8 @@ public:
     FuncContains=0, FuncNotContains,
     FuncEquals, FuncNotEquals,
     FuncRegExp, FuncNotRegExp,
-    FuncBefore, FuncAfter
+    FuncBefore, FuncAfter,
+    FuncLess, FuncGreater
   };
 
   FilterRule();
@@ -102,6 +101,8 @@ private:
   bool matchesRegExp(Data::EntryPtr entry) const;
   bool before(Data::EntryPtr entry) const;
   bool after(Data::EntryPtr entry) const;
+  bool lessThan(Data::EntryPtr entry) const;
+  bool greaterThan(Data::EntryPtr entry) const;
   void updatePattern();
 
   QString m_fieldName;
