@@ -34,7 +34,7 @@ SpinBox::SpinBox(int min_, int max_, QWidget * parent_) : QSpinBox(parent_) {
   setAlignment(Qt::AlignRight);
   // I want to be able to have an empty value
   // an empty string just removes the special value, so set white space
-  setSpecialValueText(QLatin1String(" "));
+  setSpecialValueText(QStringLiteral(" "));
   connect(lineEdit(), SIGNAL(textChanged(const QString&)), SLOT(checkValue(const QString&)));
 }
 
