@@ -27,8 +27,7 @@
 
 #include "fieldwidget.h"
 
-#include <krun.h>
-#include <kurlcompletion.h>
+#include <KUrlCompletion>
 
 #include <QPointer>
 
@@ -47,29 +46,28 @@ public:
   URLFieldWidget(Data::FieldPtr field, QWidget* parent);
   virtual ~URLFieldWidget();
 
-  virtual QString text() const;
-  virtual void setTextImpl(const QString& text);
+  virtual QString text() const Q_DECL_OVERRIDE;
+  virtual void setTextImpl(const QString& text) Q_DECL_OVERRIDE;
 
-public slots:
-  virtual void clearImpl();
+public Q_SLOTS:
+  virtual void clearImpl() Q_DECL_OVERRIDE;
 
 protected:
-  virtual QWidget* widget();
-  virtual void updateFieldHook(Data::FieldPtr oldField, Data::FieldPtr newField);
+  virtual QWidget* widget() Q_DECL_OVERRIDE;
+  virtual void updateFieldHook(Data::FieldPtr oldField, Data::FieldPtr newField) Q_DECL_OVERRIDE;
 
-protected slots:
+protected Q_SLOTS:
   void slotOpenURL(const QString& url);
 
 private:
   class URLCompletion : public KUrlCompletion {
   public:
     URLCompletion() : KUrlCompletion() {}
-    virtual QString makeCompletion(const QString& text);
+    virtual QString makeCompletion(const QString& text) Q_DECL_OVERRIDE;
   };
 
   KUrlRequester* m_requester;
-  bool m_isRelative : 1;
-  QPointer<KRun> m_run;
+  bool m_isRelative;
 };
 
   } // end GUI namespace
