@@ -154,7 +154,7 @@ Tellico::Data::CollPtr ImportDialog::collection() {
             ProgressManager::self(), SLOT(setTotalSteps(QObject*, qulonglong)));
     connect(m_importer, SIGNAL(signalProgress(QObject*, qulonglong)),
             ProgressManager::self(), SLOT(setProgress(QObject*, qulonglong)));
-    connect(&item, SIGNAL(signalCancelled(ProgressItem*)), m_importer, SLOT(slotCancel()));
+    connect(&item, &Tellico::ProgressItem::signalCancelled, m_importer, &Tellico::Import::Importer::slotCancel);
     ProgressItem::Done done(m_importer);
     m_coll = m_importer->collection();
   }
@@ -209,7 +209,7 @@ Tellico::Import::Importer* ImportDialog::importer(Tellico::Import::Format format
       CHECK_SIZE;
       importer = new Import::XSLTImporter(firstURL);
       {
-        QString xsltFile = DataFileRegistry::self()->locate(QLatin1String("mods2tellico.xsl"));
+        QString xsltFile = DataFileRegistry::self()->locate(QStringLiteral("mods2tellico.xsl"));
         if(!xsltFile.isEmpty()) {
           QUrl u = QUrl::fromLocalFile(xsltFile);
           static_cast<Import::XSLTImporter*>(importer)->setXSLTURL(u);
@@ -413,7 +413,7 @@ QString ImportDialog::startDir(Tellico::Import::Format format_) {
   if(format_ == Import::GCstar) {
     QDir dir = QDir::home();
     // able to cd if exists and readable
-    if(dir.cd(QLatin1String(".local/share/gcstar/"))) {
+    if(dir.cd(QStringLiteral(".local/share/gcstar/"))) {
       return dir.absolutePath();
     }
   }
@@ -445,7 +445,7 @@ Tellico::Data::CollPtr ImportDialog::importURL(Tellico::Import::Format format_,
           ProgressManager::self(), SLOT(setTotalSteps(QObject*, qulonglong)));
   connect(imp, SIGNAL(signalProgress(QObject*, qulonglong)),
           ProgressManager::self(), SLOT(setProgress(QObject*, qulonglong)));
-  connect(&item, SIGNAL(signalCancelled(ProgressItem*)), imp, SLOT(slotCancel()));
+  connect(&item, &Tellico::ProgressItem::signalCancelled, imp, &Tellico::Import::Importer::slotCancel);
   ProgressItem::Done done(imp);
 
   Data::CollPtr c = imp->collection();
@@ -469,7 +469,7 @@ Tellico::Data::CollPtr ImportDialog::importText(Tellico::Import::Format format_,
           ProgressManager::self(), SLOT(setTotalSteps(QObject*, qulonglong)));
   connect(imp, SIGNAL(signalProgress(QObject*, qulonglong)),
           ProgressManager::self(), SLOT(setProgress(QObject*, qulonglong)));
-  connect(&item, SIGNAL(signalCancelled(ProgressItem*)), imp, SLOT(slotCancel()));
+  connect(&item, &Tellico::ProgressItem::signalCancelled, imp, &Tellico::Import::Importer::slotCancel);
   ProgressItem::Done done(imp);
 */
   Data::CollPtr c = imp->collection();
