@@ -43,7 +43,7 @@ void IBSFetcherTest::initTestCase() {
 
 void IBSFetcherTest::testTitle() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Book, Tellico::Fetch::Title,
-                                       QLatin1String("Vino & cucina"));
+                                       QStringLiteral("Vino & cucina"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::IBSFetcher(this));
 
   // the one we want should be in the first 5
@@ -52,7 +52,7 @@ void IBSFetcherTest::testTitle() {
   QVERIFY(results.size() > 0);
   Tellico::Data::EntryPtr entry;  //  results can be randomly ordered, loop until we find the one we want
   foreach(Tellico::Data::EntryPtr testEntry, results) {
-    if(testEntry->field(QLatin1String("isbn")) == QLatin1String("8804620374")) {
+    if(testEntry->field(QStringLiteral("isbn")) == QStringLiteral("8804620374")) {
       entry = testEntry;
       break;
     }
@@ -64,7 +64,7 @@ void IBSFetcherTest::testTitle() {
 
 void IBSFetcherTest::testIsbn() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Book, Tellico::Fetch::ISBN,
-                                       QLatin1String("9788804620372"));
+                                       QStringLiteral("9788804620372"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::IBSFetcher(this));
 
   Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
@@ -75,7 +75,7 @@ void IBSFetcherTest::testIsbn() {
 
 void IBSFetcherTest::testTranslator() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Book, Tellico::Fetch::ISBN,
-                                       QLatin1String("8842914975"));
+                                       QStringLiteral("8842914975"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::IBSFetcher(this));
 
   Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
@@ -84,16 +84,16 @@ void IBSFetcherTest::testTranslator() {
 
   Tellico::Data::EntryPtr entry = results.first();
   QCOMPARE(entry->field("title"), QString::fromUtf8("città sepolta"));
-  QCOMPARE(entry->field("isbn"), QLatin1String("8842914975"));
-  QCOMPARE(entry->field("genre"), QLatin1String("Thriller"));
-  QCOMPARE(entry->field("language"), QLatin1String("italiano"));
-  QCOMPARE(entry->field("author"), QLatin1String("James Rollins"));
-  QCOMPARE(entry->field("translator"), QLatin1String("M. Zonetti"));
+  QCOMPARE(entry->field("isbn"), QStringLiteral("8842914975"));
+  QCOMPARE(entry->field("genre"), QStringLiteral("Thriller"));
+  QCOMPARE(entry->field("language"), QStringLiteral("italiano"));
+  QCOMPARE(entry->field("author"), QStringLiteral("James Rollins"));
+  QCOMPARE(entry->field("translator"), QStringLiteral("M. Zonetti"));
 }
 
 void IBSFetcherTest::testEditor() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Book, Tellico::Fetch::ISBN,
-                                       QLatin1String("8873718735"));
+                                       QStringLiteral("8873718735"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::IBSFetcher(this));
 
   Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
@@ -102,18 +102,18 @@ void IBSFetcherTest::testEditor() {
 
   Tellico::Data::EntryPtr entry = results.first();
   QCOMPARE(entry->field("title"), QString::fromUtf8("centuria bianca"));
-//  QCOMPARE(entry->field("editor"), QLatin1String("I. Armaro"));
-  QCOMPARE(entry->field("binding"), QLatin1String("Paperback"));
+//  QCOMPARE(entry->field("editor"), QStringLiteral("I. Armaro"));
+  QCOMPARE(entry->field("binding"), QStringLiteral("Paperback"));
 }
 
 void IBSFetcherTest::compareEntry(Tellico::Data::EntryPtr entry) {
-  QVERIFY(entry->field("title").startsWith(QLatin1String("Vino & cucina")));
-  QCOMPARE(entry->field("isbn"), QLatin1String("8804620374"));
-  QCOMPARE(entry->field("author"), QLatin1String("Antonella Clerici; Bruno Vespa"));
-  QCOMPARE(entry->field("pub_year"), QLatin1String("2012"));
-  QCOMPARE(entry->field("pages"), QLatin1String("225"));
-  QCOMPARE(entry->field("publisher"), QLatin1String("Mondadori"));
+  QVERIFY(entry->field("title").startsWith(QStringLiteral("Vino & cucina")));
+  QCOMPARE(entry->field("isbn"), QStringLiteral("8804620374"));
+  QCOMPARE(entry->field("author"), QStringLiteral("Antonella Clerici; Bruno Vespa"));
+  QCOMPARE(entry->field("pub_year"), QStringLiteral("2012"));
+  QCOMPARE(entry->field("pages"), QStringLiteral("225"));
+  QCOMPARE(entry->field("publisher"), QStringLiteral("Mondadori"));
   QVERIFY(!entry->field("plot").isEmpty());
   QVERIFY(!entry->field("cover").isEmpty());
-  QVERIFY(!entry->field(QLatin1String("cover")).contains(QLatin1Char('/')));
+  QVERIFY(!entry->field(QStringLiteral("cover")).contains(QLatin1Char('/')));
 }
