@@ -35,13 +35,12 @@ public:
 private Q_SLOTS:
   void initTestCase();
   void testSnowyRiver();
-  void testSnowyRiverFr();
-  void testSnowyRiverEs();
   void testAsterix();
   void testBodyDouble();
   void testMary();
   void testOkunen();
   void testFetchResultEncoding();
+  void testBabel();
 };
 
 #endif
