@@ -51,7 +51,7 @@ void VideoGameGeekFetcherTest::initTestCase() {
 
 void VideoGameGeekFetcherTest::testTitle() {
   Tellico::Fetch::FetchRequest request(Tellico::Data::Collection::Game, Tellico::Fetch::Title,
-                                       QLatin1String("Mass Effect 3: Citadel"));
+                                       QStringLiteral("Mass Effect 3: Citadel"));
   Tellico::Fetch::Fetcher::Ptr fetcher(new Tellico::Fetch::VideoGameGeekFetcher(this));
 
   Tellico::Data::EntryList results = DO_FETCH1(fetcher, request, 1);
@@ -60,13 +60,13 @@ void VideoGameGeekFetcherTest::testTitle() {
 
   Tellico::Data::EntryPtr entry = results.at(0);
   QCOMPARE(entry->collection()->type(), Tellico::Data::Collection::Game);
-  QCOMPARE(entry->field(QLatin1String("title")), QLatin1String("Mass Effect 3: Citadel"));
-  QCOMPARE(entry->field(QLatin1String("developer")), QLatin1String("BioWare"));
-  QCOMPARE(entry->field(QLatin1String("publisher")), QLatin1String("Electronic Arts Inc. (EA)"));
-  QCOMPARE(entry->field(QLatin1String("year")), QLatin1String("2013"));
-//  QCOMPARE(entry->field(QLatin1String("platform")), QLatin1String("PlayStation3"));
+  QCOMPARE(entry->field(QStringLiteral("title")), QStringLiteral("Mass Effect 3: Citadel"));
+  QCOMPARE(entry->field(QStringLiteral("developer")), QStringLiteral("BioWare"));
+  QCOMPARE(entry->field(QStringLiteral("publisher")), QStringLiteral("Electronic Arts Inc. (EA)"));
+  QCOMPARE(entry->field(QStringLiteral("year")), QStringLiteral("2013"));
+//  QCOMPARE(entry->field(QStringLiteral("platform")), QStringLiteral("PlayStation3"));
   QCOMPARE(set(entry, "genre"), set("Action RPG; Shooter"));
   // the cover image got removed for some reason
-//  QVERIFY(!entry->field(QLatin1String("cover")).isEmpty());
-  QVERIFY(!entry->field(QLatin1String("description")).isEmpty());
+//  QVERIFY(!entry->field(QStringLiteral("cover")).isEmpty());
+  QVERIFY(!entry->field(QStringLiteral("description")).isEmpty());
 }
