@@ -49,7 +49,7 @@ public:
   virtual QWidget* widget(QWidget* parent) Q_DECL_OVERRIDE;
 
 public Q_SLOTS:
-  void slotCancel() {}
+  void slotCancel() Q_DECL_OVERRIDE {}
 
 private:
   QString text() const;
